@@ -3,6 +3,9 @@ from bs4 import BeautifulSoup
 import feedparser
 import re
 
+### Configuration ###
+POSSIBLE_FEED_KEYS = ['link', 'id', 'published', 'title', 'summary']
+
 ### Enumerated Types ###
 def enum(*sequential, **named):
     enums = dict(zip(sequential, range(len(sequential))), **named)
@@ -29,7 +32,7 @@ def get_count_for_user_href(soup, user, suffix):
 
 def build_feed_item(item):
     dict = {}
-    keys = ['link', 'id', 'published', 'title', 'summary']
+    keys = POSSIBLE_FEED_KEYS
     for key in keys:
         if key in item.keys():
             dict[key] = item[key]
@@ -50,6 +53,9 @@ def check_activity_type(description):
         else:  # hopefully.
             return ACTIVITY_ITEM_TYPES.USER_FOLLOW
 
+def is_new_ui(soup):
+    return soup.find('div', attrs={'class': 'ProfileTabs'}) is not None
+
 ####################################################################
 # API
 ####################################################################
@@ -58,32 +64,48 @@ class Quora:
     @staticmethod
     def get_user_stats(user):
         soup = BeautifulSoup(requests.get('http://www.quora.com/' + user).text)
-        user_dict = { 'username': user }
-        user_dict['name'] = soup.find('h1').find('span', class_='user').string
+        user_dict = {'username': user}
 
-        if soup.find('div', class_="empty_area br10 light") is not None:
-            attributes = ['Followers', 'Following', 'Topics', 'Blogs', 'Posts', 'Questions', 'Answers', 'Reviews', 'Edits']
-
-            for item in soup.findAll('li', class_="tab #"):
-                label = item.find('strong').string
-                if label in attributes:
-                    user_dict[label.lower()] = try_cast(item.find('span').string)
-        else:
-            attributes_to_href_suffix = {
-                'followers': 'followers',
-                'following': 'following',
-                'topics': 'topics',
-                'blogs': 'blogs',
-                'posts': 'all_posts',
-                'questions': 'questions',
-                'answers': 'answers',
-                'edits': 'log'
+        if is_new_ui(soup):
+            classes_to_attributes = {
+                'ProfileTabsFollowers': 'followers',
+                'ProfileTabsFollowing': 'following',
+                'ProfileTabsQuestions': 'questions',
+                'ProfileTabsAnswers': 'answers',
+                'ProfileTabsPosts': 'posts',
+                'ProfileTabsReviews': 'reviews',
+                'ProfileTabsOperations': 'edits'
             }
-            for attribute, suffix in attributes_to_href_suffix.iteritems():
-                try:
-                    user_dict[attribute] = get_count_for_user_href(soup, user, suffix)
-                except:
-                    pass
+            for item in soup.find('div', attrs={'class': 'ProfileTabs'}).findAll('li'):
+                for key in classes_to_attributes.keys():
+                    if key in item.get("class"):
+                        user_dict[classes_to_attributes[key]] = try_cast(item.find('span').string)
+        else:
+            user_dict['name'] = soup.find('h1').find('span', class_='user').string
+
+            if soup.find('div', class_="empty_area br10 light") is not None:
+                attributes = ['Followers', 'Following', 'Topics', 'Blogs', 'Posts', 'Questions', 'Answers', 'Reviews', 'Edits']
+
+                for item in soup.findAll('li', class_="tab #"):
+                    label = item.find('strong').string
+                    if label in attributes:
+                        user_dict[label.lower()] = try_cast(item.find('span').string)
+            else:
+                attributes_to_href_suffix = {
+                    'followers': 'followers',
+                    'following': 'following',
+                    'topics': 'topics',
+                    'blogs': 'blogs',
+                    'posts': 'all_posts',
+                    'questions': 'questions',
+                    'answers': 'answers',
+                    'edits': 'log'
+                }
+                for attribute, suffix in attributes_to_href_suffix.iteritems():
+                    try:
+                        user_dict[attribute] = get_count_for_user_href(soup, user, suffix)
+                    except:
+                        pass
         return user_dict
 
     @staticmethod
@@ -118,6 +140,10 @@ class Quora:
                     activity.questions.append(build_feed_item(entry))
         return activity
 
+    @staticmethod
+    def get_activity_keys():
+        return POSSIBLE_FEED_KEYS
+
 class Activity:
     def __init__(self, upvotes=[], user_follows=[], question_follows=[], answers=[], questions=[]):
         self.upvotes = upvotes
